@@ -1,32 +1,35 @@
+//////////////////// Copyright ///////////////////////// {{{1
+
 //
 // Copyright (c) 2010, Roland Kaminski <kaminski@cs.uni-potsdam.de>
 //
 // This file is part of aspcud.
 //
-// gringo is free software: you can redistribute it and/or modify
+// aspcud is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
 //
-// gringo is distributed in the hope that it will be useful,
+// aspcud is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
 //
 // You should have received a copy of the GNU General Public License
-// along with gringo.  If not, see <http://www.gnu.org/licenses/>.
+// along with aspcud.  If not, see <http://www.gnu.org/licenses/>.
 //
 
+//////////////////// Preamble ////////////////////////// {{{1
+
 #include <cudf/packages.h>
 
-namespace Cudf
-{
+//////////////////// PackageRef //////////////////////// {{{1
+
+namespace Cudf {
 
 	PackageRef::PackageRef(uint32_t name, RelOp op, int32_t version)
 		: name(name)
 		, op(op)
-		, version(version)
-	{
-	}
+		, version(version) { }
 
 }
